@@ -5,6 +5,7 @@ use crate::text;
 
 use super::Conversation;
 use super::PublicChannel;
+use super::User;
 
 /// # Select Element Builder
 /// Use to construct a Select element
@@ -157,4 +158,35 @@ impl<'a> SelectBuilder<'a> {
             None => sel,
         }
     }
+
+    /// Set the data source to "users". See docs for `select::User` for more info.
+    ///
+    /// # Example
+    /// ```
+    /// use std::iter;
+    /// use std::convert::TryFrom;
+    ///
+    /// use slack_blocks::{
+    ///   text,
+    ///   text::ToSlackPlaintext,
+    ///   blocks::{Block, Section, Actions},
+    ///   block_elements::{BlockElement, select::Select},
+    /// };
+    ///
+    /// let select: BlockElement = Select::from_placeholder_and_action_id("Choose a user to ban!!", "ban_chosen")
+    ///                                   .choose_from_users()
+    ///                                   .into();
+    ///
+    /// let blocks: Block = Actions::try_from(select).unwrap().into();
+    ///
+    /// // <send `blocks` to slack's API>
+    /// ```
+    pub fn choose_from_users(self) -> User<'a> {
+        let sel = User::from_placeholder_and_action_id(self.placeholder, self.action_id);
+
+        match self.confirm {
+            Some(confirm) => sel.with_confirm(confirm),
+            None => sel,
+        }
+    }
 }
